@@ -8,5 +8,7 @@
 #include <phat/phatkeyboard.h>
 #include <phat/phatvkeyboard.h>
 #include <phat/phathkeyboard.h>
+#include <phat/phatpad.h>
+#include <phat/phatknob.h>
 
 #endif /* __PHAT_H__ */
